@@ -18,6 +18,7 @@ import requests
 from requests.adapters import HTTPAdapter
 from requests.exceptions import Timeout
 from requests.packages import urllib3
+from requests.packages.urllib3.util.ssl_ import create_urllib3_context
 from six.moves.urllib.parse import urlparse
 
 from . import __title__, __version__
@@ -39,6 +40,7 @@ class API(object):
         server="my.geotab.com",
         timeout=DEFAULT_TIMEOUT,
         proxies=None,
+        cert=None,
     ):
         """Initialize the MyGeotab API object with credentials.
 
@@ -56,6 +58,8 @@ class API(object):
         :type timeout: float or None
         :param proxies: The proxies dictionary to apply to the request.
         :type proxies: dict or None
+        :param cert: The path to client certificate. A single path to .pem file or a Tuple (.cer file, .key file).
+        :type cert: str or Tuple or None
         :raise Exception: Raises an Exception if a username, or one of the session_id or password is not provided.
         """
         if username is None:
@@ -68,6 +72,7 @@ class API(object):
         self.timeout = timeout
         self._proxies = proxies
         self.__reauthorize_count = 0
+        self._cert = cert
 
     @property
     def _server(self):
@@ -105,13 +110,21 @@ class API(object):
 
         try:
             result = _query(
-                self._server, method, params, self.timeout, verify_ssl=self._is_verify_ssl, proxies=self._proxies
+                self._server,
+                method,
+                params,
+                self.timeout,
+                verify_ssl=self._is_verify_ssl,
+                proxies=self._proxies,
+                cert=self._cert,
             )
             if result is not None:
                 self.__reauthorize_count = 0
             return result
         except MyGeotabException as exception:
-            if exception.name == "InvalidUserException":
+            if exception.name == "InvalidUserException" or (
+                exception.name == "DbUnavailableException" and "Initializing" in exception.message
+            ):
                 if self.__reauthorize_count == 0 and self.credentials.password:
                     self.__reauthorize_count += 1
                     self.authenticate()
@@ -219,6 +232,7 @@ class API(object):
                 self.timeout,
                 verify_ssl=self._is_verify_ssl,
                 proxies=self._proxies,
+                cert=self._cert,
             )
             if result:
                 if "path" not in result and self.credentials.session_id:
@@ -234,7 +248,9 @@ class API(object):
                 )
                 return self.credentials
         except MyGeotabException as exception:
-            if exception.name == "InvalidUserException":
+            if exception.name == "InvalidUserException" or (
+                exception.name == "DbUnavailableException" and "Initializing" in exception.message
+            ):
                 raise AuthenticationException(
                     self.credentials.username, self.credentials.database, self.credentials.server
                 )
@@ -302,12 +318,17 @@ class GeotabHTTPAdapter(HTTPAdapter):
     """HTTP adapter to force use of TLS 1.2 for HTTPS connections."""
 
     def init_poolmanager(self, connections, maxsize, block=False, **pool_kwargs):
+        ssl_context = create_urllib3_context(ssl_version=ssl.PROTOCOL_TLS)
+        ssl_context.options |= ssl.OP_NO_SSLv2
+        ssl_context.options |= ssl.OP_NO_SSLv3
+        ssl_context.options |= ssl.OP_NO_TLSv1
+        ssl_context.options |= ssl.OP_NO_TLSv1_1
         self.poolmanager = urllib3.poolmanager.PoolManager(
-            num_pools=connections, maxsize=maxsize, block=block, ssl_version=ssl.PROTOCOL_TLSv1_2, **pool_kwargs
+            num_pools=connections, maxsize=maxsize, block=block, ssl_context=ssl_context, **pool_kwargs
         )
 
 
-def _query(server, method, parameters, timeout=DEFAULT_TIMEOUT, verify_ssl=True, proxies=None):
+def _query(server, method, parameters, timeout=DEFAULT_TIMEOUT, verify_ssl=True, proxies=None, cert=None):
     """Formats and performs the query against the API.
 
     :param server: The MyGeotab server.
@@ -322,6 +343,8 @@ def _query(server, method, parameters, timeout=DEFAULT_TIMEOUT, verify_ssl=True,
     :type verify_ssl: bool
     :param proxies: The proxies dictionary to apply to the request.
     :type proxies: dict or None
+    :param cert: The path to client certificate. A single path to .pem file or a Tuple (.cer file, .pem file)
+    :type cert: str or Tuple or None
     :raise MyGeotabException: Raises when an exception occurs on the MyGeotab server.
     :raise TimeoutException: Raises when the request does not respond after some time.
     :raise urllib2.HTTPError: Raises when there is an HTTP status code that indicates failure.
@@ -332,6 +355,8 @@ def _query(server, method, parameters, timeout=DEFAULT_TIMEOUT, verify_ssl=True,
     headers = get_headers()
     with requests.Session() as session:
         session.mount("https://", GeotabHTTPAdapter())
+        if cert:
+            session.cert = cert
         try:
             response = session.post(
                 api_endpoint,
